import { JscTarget } from '@swc/core';
import { RollupOptions, InputOptions, OutputOptions } from 'rollup';

type ExportType = 'require' | 'export' | 'default' | string;
type CommonConfig = {
    dts?: boolean;
    format?: OutputOptions['format'];
    minify?: boolean;
    sourcemap?: boolean;
    external?: string[];
    runtime?: string;
    exportCondition?: {
        source: string;
        name: string;
        export: ExportCondition;
    };
};
type ExportCondition = string | Record<ExportType, string>;
type BuncheeRollupConfig = Partial<Omit<RollupOptions, 'input' | 'output'>> & {
    exportName?: string;
    input: InputOptions;
    output: OutputOptions[];
    dtsOnly: boolean;
};
type CliArgs = CommonConfig & {
    file?: string;
    watch?: boolean;
    cwd?: string;
    target?: JscTarget;
};

declare function bundle(entryPath: string, { cwd, ...options }?: CliArgs): Promise<any>;

export { BuncheeRollupConfig, CliArgs, bundle };
